Coverage report

# Coverage report: 90.39%

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
Total | 1004 | 84 | 12 | 172 | 29 | 90.39%
/home/chris/workspace/django-shop/shop/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/addressmodel/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/addressmodel/admin | 9 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/addressmodel/models | 34 | 3 | 0 | 0 | 0 | 91.18%
/home/chris/workspace/django-shop/shop/admin/__init__ | 1 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/admin/orderadmin | 28 | 0 | 0 | 2 | 1 | 96.67%
/home/chris/workspace/django-shop/shop/backends_pool | 42 | 0 | 0 | 12 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/cart/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/cart/cart_modifiers_base | 9 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/cart/modifiers/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/cart/modifiers/rebate_modifiers | 11 | 0 | 0 | 2 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/cart/modifiers/tax_modifiers | 18 | 0 | 0 | 2 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/cart/modifiers_pool | 32 | 0 | 0 | 6 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/forms | 11 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/models/__init__ | 6 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/models/cartmodel | 87 | 2 | 0 | 20 | 2 | 96.26%
/home/chris/workspace/django-shop/shop/models/ordermodel | 166 | 14 | 0 | 28 | 11 | 87.11%
/home/chris/workspace/django-shop/shop/models/productmodel | 45 | 2 | 0 | 4 | 1 | 93.88%
/home/chris/workspace/django-shop/shop/order_signals | 7 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/payment/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/payment/api | 13 | 3 | 0 | 0 | 0 | 76.92%
/home/chris/workspace/django-shop/shop/payment/backends/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/payment/backends/pay_on_delivery | 13 | 3 | 0 | 0 | 0 | 76.92%
/home/chris/workspace/django-shop/shop/payment/urls | 9 | 4 | 0 | 2 | 1 | 54.55%
/home/chris/workspace/django-shop/shop/shipping/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/shipping/api | 22 | 2 | 0 | 4 | 0 | 92.31%
/home/chris/workspace/django-shop/shop/shipping/backends/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/shipping/backends/flat_rate | 21 | 5 | 0 | 0 | 0 | 76.19%
/home/chris/workspace/django-shop/shop/shipping/urls | 9 | 0 | 0 | 2 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/shop_api | 21 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/templatetags/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/templatetags/shop_tags | 28 | 2 | 0 | 2 | 0 | 93.33%
/home/chris/workspace/django-shop/shop/urls | 8 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/util/__init__ | 0 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/util/address | 43 | 4 | 0 | 16 | 4 | 86.44%
/home/chris/workspace/django-shop/shop/util/cart | 21 | 0 | 0 | 10 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/util/fields | 12 | 0 | 6 | 6 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/util/loader | 25 | 0 | 0 | 6 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/util/order | 23 | 0 | 0 | 12 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/views/__init__ | 6 | 0 | 6 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/views/cart | 79 | 2 | 0 | 12 | 2 | 95.60%
/home/chris/workspace/django-shop/shop/views/checkout | 115 | 37 | 0 | 22 | 6 | 68.61%
/home/chris/workspace/django-shop/shop/views/order | 20 | 0 | 0 | 0 | 0 | 100.00%
/home/chris/workspace/django-shop/shop/views/product | 10 | 1 | 0 | 2 | 1 | 83.33%